@@ -485,6 +485,64 @@ max_framebuffers=2
             with open(os.path.join(boot_dir, 'config.txt')) as f:
                 self.assertTrue(f.read() == expected_config_txt)
 
+    def test_disable_kdump_tools_on_install(self):
+        """Test kdump-tools disabled if installed on upgrade."""
+        q = DistUpgradeQuirks(mock.Mock(), mock.Mock())
+
+        mock_pkg = make_mock_pkg(name="kdump-tools", is_installed=False)
+        mock_pkg.marked_install = True
+        mock_cache = {'kdump-tools': mock_pkg}
+
+        with mock.patch(
+            "DistUpgrade.DistUpgradeQuirks.subprocess.run"
+        ) as popen_mock:
+            q._disable_kdump_tools_on_install(mock_cache)
+
+        expected_cmd = 'echo "kdump-tools kdump-tools/use_kdump boolean false"'
+        expected_cmd += ' | debconf-set-selections'
+        popen_mock.assert_called_once_with(expected_cmd, shell=True)
+
+    def test_no_disable_kdump_tools_if_installed(self):
+        """Test kdump-tools is not disabled on upgrade if already installed."""
+        q = DistUpgradeQuirks(mock.Mock(), mock.Mock())
+
+        mock_pkg = make_mock_pkg(name="kdump-tools", is_installed=True)
+        mock_pkg.marked_install = True
+        mock_cache = {'kdump-tools': mock_pkg}
+
+        with mock.patch(
+            "DistUpgrade.DistUpgradeQuirks.subprocess.run"
+        ) as popen_mock:
+            q._disable_kdump_tools_on_install(mock_cache)
+
+        popen_mock.assert_not_called()
+
+    def test_no_disable_kdump_tools_if_not_requested(self):
+        """Test kdump-tools disable hook does nothing if not requested."""
+        q = DistUpgradeQuirks(mock.Mock(), mock.Mock())
+
+        # Do nothing if not found in cache
+        mock_cache = {}
+
+        with mock.patch(
+            "DistUpgrade.DistUpgradeQuirks.subprocess.run"
+        ) as popen_mock:
+            q._disable_kdump_tools_on_install(mock_cache)
+
+        popen_mock.assert_not_called()
+
+        # Do nothing if not requested for install
+        mock_pkg = make_mock_pkg(name="kdump-tools", is_installed=False)
+        mock_pkg.marked_install = False
+        mock_cache = {'kdump-tools': mock_pkg}
+
+        with mock.patch(
+            "DistUpgrade.DistUpgradeQuirks.subprocess.run"
+        ) as popen_mock:
+            q._disable_kdump_tools_on_install(mock_cache)
+
+        popen_mock.assert_not_called()
+
 
 class TestSnapQuirks(unittest.TestCase):
 
@@ -506,8 +564,8 @@ class TestSnapQuirks(unittest.TestCase):
         controller = mock.Mock()
         config = mock.Mock()
         q = DistUpgradeQuirks(controller, config)
-        q._from_version = "20.04"
-        q._to_version = "22.04"
+        q._from_version = "24.04"
+        q._to_version = "24.10"
         # Call method under test
 
         controller.cache = {
@@ -555,19 +613,30 @@ class TestSnapQuirks(unittest.TestCase):
         self.maxDiff = None
         self.assertDictEqual(
             q._snap_list,
-            {'core22': {
+            {'core24': {
                 'channel': 'stable',
                 'command': 'install',
                 'deb': None, 'snap-id': '1234'},
-             'gnome-42-2204': {
-                'channel': 'stable/ubuntu-22.04',
+             'gnome-46-2404': {
+                'channel': 'stable/ubuntu-24.10',
                 'command': 'install',
                 'deb': None, 'snap-id': '1234'},
+             'mesa-2404': {
+                'channel': 'stable/ubuntu-24.10',
+                'command': 'install',
+                'deb': None,
+                'snap-id': '1234'},
              'snap-store': {
-                'channel': 'stable/ubuntu-22.04',
+                'channel': '2/stable/ubuntu-24.10',
                 'command': 'install',
                 'deb': 'gnome-software',
-                'snap-id': '1234'}})
+                'snap-id': '1234'},
+             'thunderbird': {
+                'channel': 'stable/ubuntu-24.10',
+                'command': 'install',
+                'deb': None,
+                'snap-id': '1234'}}
+        )
 
     def test_is_deb2snap_metapkg_installed(self):
         # Prepare the state for testing
